# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/attachment_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/attachment_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import attachment_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_attachment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1olvid/daemon/command/v1/attachment_commands.proto\x12\x17olvid.daemon.command.v1\x1a*olvid/daemon/datatypes/v1/attachment.proto\"l\n\x15\x41ttachmentListRequest\x12H\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.AttachmentFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"a\n\x16\x41ttachmentListResponse\x12G\n\x0b\x61ttachments\x18\x01 \x03(\x0b\x32%.olvid.daemon.datatypes.v1.AttachmentR\x0b\x61ttachments\"d\n\x14\x41ttachmentGetRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\"^\n\x15\x41ttachmentGetResponse\x12\x45\n\nattachment\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.AttachmentR\nattachment\"\xaf\x01\n\x17\x41ttachmentDeleteRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\x12\x30\n\x11\x64\x65lete_everywhere\x18\x02 \x01(\x08H\x00R\x10\x64\x65leteEverywhere\x88\x01\x01\x42\x14\n\x12_delete_everywhere\"\x1a\n\x18\x41ttachmentDeleteResponse\"i\n\x19\x41ttachmentDownloadRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\"2\n\x1a\x41ttachmentDownloadResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunkB\xc6\x01\n\x1b\x63om.olvid.daemon.command.v1B\x17\x41ttachmentCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.attachment_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\027AttachmentCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_ATTACHMENTLISTREQUEST']._serialized_start=122
  _globals['_ATTACHMENTLISTREQUEST']._serialized_end=230
  _globals['_ATTACHMENTLISTRESPONSE']._serialized_start=232
  _globals['_ATTACHMENTLISTRESPONSE']._serialized_end=329
  _globals['_ATTACHMENTGETREQUEST']._serialized_start=331
  _globals['_ATTACHMENTGETREQUEST']._serialized_end=431
  _globals['_ATTACHMENTGETRESPONSE']._serialized_start=433
  _globals['_ATTACHMENTGETRESPONSE']._serialized_end=527
  _globals['_ATTACHMENTDELETEREQUEST']._serialized_start=530
  _globals['_ATTACHMENTDELETEREQUEST']._serialized_end=705
  _globals['_ATTACHMENTDELETERESPONSE']._serialized_start=707
  _globals['_ATTACHMENTDELETERESPONSE']._serialized_end=733
  _globals['_ATTACHMENTDOWNLOADREQUEST']._serialized_start=735
  _globals['_ATTACHMENTDOWNLOADREQUEST']._serialized_end=840
  _globals['_ATTACHMENTDOWNLOADRESPONSE']._serialized_start=842
  _globals['_ATTACHMENTDOWNLOADRESPONSE']._serialized_end=892
# @@protoc_insertion_point(module_scope)
