####
# WARNING: DO NOT EDIT: this code is automatically generated, see overlay_generator/generate_protobuf_overlay
####

from ..notifications import *
from ..commands import *
from ..admin import *

from typing import Union


NotificationMessageType = Union[SubscribeToAttachmentReceivedNotification, AttachmentReceivedNotification, SubscribeToAttachmentUploadedNotification, AttachmentUploadedNotification, SubscribeToCallIncomingCallNotification, CallIncomingCallNotification, SubscribeToCallRingingNotification, CallRingingNotification, SubscribeToCallAcceptedNotification, CallAcceptedNotification, SubscribeToCallDeclinedNotification, CallDeclinedNotification, SubscribeToCallBusyNotification, CallBusyNotification, SubscribeToCallEndedNotification, CallEndedNotification, SubscribeToContactNewNotification, ContactNewNotification, SubscribeToContactDeletedNotification, ContactDeletedNotification, SubscribeToContactDetailsUpdatedNotification, ContactDetailsUpdatedNotification, SubscribeToContactPhotoUpdatedNotification, ContactPhotoUpdatedNotification, SubscribeToDiscussionNewNotification, DiscussionNewNotification, SubscribeToDiscussionLockedNotification, DiscussionLockedNotification, SubscribeToDiscussionTitleUpdatedNotification, DiscussionTitleUpdatedNotification, SubscribeToDiscussionSettingsUpdatedNotification, DiscussionSettingsUpdatedNotification, SubscribeToGroupNewNotification, GroupNewNotification, SubscribeToGroupDeletedNotification, GroupDeletedNotification, SubscribeToGroupNameUpdatedNotification, GroupNameUpdatedNotification, SubscribeToGroupPhotoUpdatedNotification, GroupPhotoUpdatedNotification, SubscribeToGroupDescriptionUpdatedNotification, GroupDescriptionUpdatedNotification, SubscribeToGroupPendingMemberAddedNotification, GroupPendingMemberAddedNotification, SubscribeToGroupPendingMemberRemovedNotification, GroupPendingMemberRemovedNotification, SubscribeToGroupMemberJoinedNotification, GroupMemberJoinedNotification, SubscribeToGroupMemberLeftNotification, GroupMemberLeftNotification, SubscribeToGroupOwnPermissionsUpdatedNotification, GroupOwnPermissionsUpdatedNotification, SubscribeToGroupMemberPermissionsUpdatedNotification, GroupMemberPermissionsUpdatedNotification, SubscribeToIdentityCreatedNotification, IdentityCreatedNotification, SubscribeToIdentityDeletedNotification, IdentityDeletedNotification, SubscribeToIdentityUpdatedNotification, IdentityDetailsUpdatedNotification, SubscribeToInvitationReceivedNotification, InvitationReceivedNotification, SubscribeToInvitationSentNotification, InvitationSentNotification, SubscribeToInvitationDeletedNotification, InvitationDeletedNotification, SubscribeToInvitationUpdatedNotification, InvitationUpdatedNotification, SubscribeToMessageReceivedNotification, MessageReceivedNotification, SubscribeToMessageSentNotification, MessageSentNotification, SubscribeToMessageDeletedNotification, MessageDeletedNotification, SubscribeToMessageBodyUpdatedNotification, MessageBodyUpdatedNotification, SubscribeToMessageUploadedNotification, MessageUploadedNotification, SubscribeToMessageDeliveredNotification, MessageDeliveredNotification, SubscribeToMessageReadNotification, MessageReadNotification, SubscribeToMessageLocationReceivedNotification, MessageLocationReceivedNotification, SubscribeToMessageLocationSentNotification, MessageLocationSentNotification, SubscribeToMessageLocationSharingStartNotification, MessageLocationSharingStartNotification, SubscribeToMessageLocationSharingUpdateNotification, MessageLocationSharingUpdateNotification, SubscribeToMessageLocationSharingEndNotification, MessageLocationSharingEndNotification, SubscribeToMessageReactionAddedNotification, MessageReactionAddedNotification, SubscribeToMessageReactionUpdatedNotification, MessageReactionUpdatedNotification, SubscribeToMessageReactionRemovedNotification, MessageReactionRemovedNotification]
CommandRequestMessageType = Union[BackupKeyGetRequest, BackupKeyRenewRequest, BackupGetRequest, BackupNowRequest, BackupRestoreDaemonRequest, BackupRestoreAdminBackupRequest, BackupRestoreProfileSnapshotRequest, ClientKeyListRequest, ClientKeyGetRequest, ClientKeyNewRequest, ClientKeyDeleteRequest, IdentityListRequest, IdentityAdminGetRequest, IdentityAdminGetBytesIdentifierRequest, IdentityAdminGetInvitationLinkRequest, IdentityAdminDownloadPhotoRequest, IdentityNewRequest, IdentityKeycloakNewRequest, IdentityDeleteRequest, AttachmentListRequest, AttachmentGetRequest, AttachmentDeleteRequest, AttachmentDownloadRequest, CallStartDiscussionCallRequest, CallStartCustomCallRequest, ContactListRequest, ContactGetRequest, ContactGetBytesIdentifierRequest, ContactGetInvitationLinkRequest, ContactDeleteRequest, ContactIntroductionRequest, ContactInviteToOneToOneDiscussionRequest, ContactDowngradeOneToOneDiscussionRequest, ContactDownloadPhotoRequest, ContactRecreateChannelsRequest, DiscussionListRequest, DiscussionGetRequest, DiscussionGetBytesIdentifierRequest, DiscussionGetByContactRequest, DiscussionGetByGroupRequest, DiscussionEmptyRequest, DiscussionDownloadPhotoRequest, DiscussionLockedListRequest, DiscussionLockedDeleteRequest, GroupListRequest, GroupGetRequest, GroupGetBytesIdentifierRequest, GroupNewStandardGroupRequest, GroupNewControlledGroupRequest, GroupNewReadOnlyGroupRequest, GroupNewAdvancedGroupRequest, GroupDisbandRequest, GroupLeaveRequest, GroupUpdateRequest, GroupUnsetPhotoRequest, GroupSetPhotoRequest, GroupDownloadPhotoRequest, IdentityGetRequest, IdentityGetBytesIdentifierRequest, IdentityGetInvitationLinkRequest, IdentityUpdateDetailsRequest, IdentityRemovePhotoRequest, IdentitySetPhotoRequest, IdentityDownloadPhotoRequest, IdentityGetApiKeyStatusRequest, IdentitySetApiKeyRequest, IdentitySetConfigurationLinkRequest, InvitationListRequest, InvitationGetRequest, InvitationNewRequest, InvitationAcceptRequest, InvitationDeclineRequest, InvitationSasRequest, InvitationDeleteRequest, KeycloakBindIdentityRequest, KeycloakUnbindIdentityRequest, KeycloakUserListRequest, KeycloakAddUserAsContactRequest, KeycloakGetApiCredentialsRequest, MessageListRequest, MessageGetRequest, MessageRefreshRequest, MessageDeleteRequest, MessageSendRequest, MessageSendWithAttachmentsRequest, MessageSendLocationRequest, MessageStartLocationSharingRequest, MessageUpdateLocationSharingRequest, MessageEndLocationSharingRequest, MessageReactRequest, MessageUpdateBodyRequest, SettingsIdentityGetRequest, SettingsIdentitySetRequest, SettingsDiscussionGetRequest, SettingsDiscussionSetRequest, StorageListRequest, StorageGetRequest, StorageSetRequest, StorageUnsetRequest, DiscussionStorageListRequest, DiscussionStorageGetRequest, DiscussionStorageSetRequest, DiscussionStorageUnsetRequest, PingRequest, DaemonVersionRequest, AuthenticationTestRequest, AuthenticationAdminTestRequest]
CommandResponseMessageType = Union[BackupKeyGetResponse, BackupKeyRenewResponse, BackupGetResponse, BackupNowResponse, BackupRestoreDaemonResponse, BackupRestoreAdminBackupResponse, BackupRestoreProfileSnapshotResponse, ClientKeyListResponse, ClientKeyGetResponse, ClientKeyNewResponse, ClientKeyDeleteResponse, IdentityListResponse, IdentityAdminGetResponse, IdentityAdminGetBytesIdentifierResponse, IdentityAdminGetInvitationLinkResponse, IdentityAdminDownloadPhotoResponse, IdentityNewResponse, IdentityKeycloakNewResponse, IdentityDeleteResponse, AttachmentListResponse, AttachmentGetResponse, AttachmentDeleteResponse, AttachmentDownloadResponse, CallStartDiscussionCallResponse, CallStartCustomCallResponse, ContactListResponse, ContactGetResponse, ContactGetBytesIdentifierResponse, ContactGetInvitationLinkResponse, ContactDeleteResponse, ContactIntroductionResponse, ContactInviteToOneToOneDiscussionResponse, ContactDowngradeOneToOneDiscussionResponse, ContactDownloadPhotoResponse, ContactRecreateChannelsResponse, DiscussionListResponse, DiscussionGetResponse, DiscussionGetBytesIdentifierResponse, DiscussionGetByContactResponse, DiscussionGetByGroupResponse, DiscussionEmptyResponse, DiscussionDownloadPhotoResponse, DiscussionLockedListResponse, DiscussionLockedDeleteResponse, GroupListResponse, GroupGetResponse, GroupGetBytesIdentifierResponse, GroupNewStandardGroupResponse, GroupNewControlledGroupResponse, GroupNewReadOnlyGroupResponse, GroupNewAdvancedGroupResponse, GroupDisbandResponse, GroupLeaveResponse, GroupUpdateResponse, GroupUnsetPhotoResponse, GroupSetPhotoResponse, GroupDownloadPhotoResponse, IdentityGetResponse, IdentityGetBytesIdentifierResponse, IdentityGetInvitationLinkResponse, IdentityUpdateDetailsResponse, IdentityRemovePhotoResponse, IdentitySetPhotoResponse, IdentityDownloadPhotoResponse, IdentityGetApiKeyStatusResponse, IdentitySetApiKeyResponse, IdentitySetConfigurationLinkResponse, InvitationListResponse, InvitationGetResponse, InvitationNewResponse, InvitationAcceptResponse, InvitationDeclineResponse, InvitationSasResponse, InvitationDeleteResponse, KeycloakBindIdentityResponse, KeycloakUnbindIdentityResponse, KeycloakUserListResponse, KeycloakAddUserAsContactResponse, KeycloakGetApiCredentialsResponse, MessageListResponse, MessageGetResponse, MessageRefreshResponse, MessageDeleteResponse, MessageSendResponse, MessageSendWithAttachmentsResponse, MessageSendLocationResponse, MessageStartLocationSharingResponse, MessageUpdateLocationSharingResponse, MessageEndLocationSharingResponse, MessageReactResponse, MessageUpdateBodyResponse, SettingsIdentityGetResponse, SettingsIdentitySetResponse, SettingsDiscussionGetResponse, SettingsDiscussionSetResponse, StorageListResponse, StorageGetResponse, StorageSetResponse, StorageUnsetResponse, DiscussionStorageListResponse, DiscussionStorageGetResponse, DiscussionStorageSetResponse, DiscussionStorageUnsetResponse, PingResponse, DaemonVersionResponse, AuthenticationTestResponse, AuthenticationAdminTestResponse]
