# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/settings_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/settings_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/olvid/daemon/command/v1/settings_commands.proto\x12\x17olvid.daemon.command.v1\x1a(olvid/daemon/datatypes/v1/settings.proto\"\x1c\n\x1aSettingsIdentityGetRequest\"w\n\x1bSettingsIdentityGetResponse\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"v\n\x1aSettingsIdentitySetRequest\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"w\n\x1bSettingsIdentitySetResponse\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"C\n\x1cSettingsDiscussionGetRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\"\x7f\n\x1dSettingsDiscussionGetResponse\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettings\"~\n\x1cSettingsDiscussionSetRequest\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettings\"\x7f\n\x1dSettingsDiscussionSetResponse\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettingsB\xc4\x01\n\x1b\x63om.olvid.daemon.command.v1B\x15SettingsCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.settings_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\025SettingsCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_SETTINGSIDENTITYGETREQUEST']._serialized_start=118
  _globals['_SETTINGSIDENTITYGETREQUEST']._serialized_end=146
  _globals['_SETTINGSIDENTITYGETRESPONSE']._serialized_start=148
  _globals['_SETTINGSIDENTITYGETRESPONSE']._serialized_end=267
  _globals['_SETTINGSIDENTITYSETREQUEST']._serialized_start=269
  _globals['_SETTINGSIDENTITYSETREQUEST']._serialized_end=387
  _globals['_SETTINGSIDENTITYSETRESPONSE']._serialized_start=389
  _globals['_SETTINGSIDENTITYSETRESPONSE']._serialized_end=508
  _globals['_SETTINGSDISCUSSIONGETREQUEST']._serialized_start=510
  _globals['_SETTINGSDISCUSSIONGETREQUEST']._serialized_end=577
  _globals['_SETTINGSDISCUSSIONGETRESPONSE']._serialized_start=579
  _globals['_SETTINGSDISCUSSIONGETRESPONSE']._serialized_end=706
  _globals['_SETTINGSDISCUSSIONSETREQUEST']._serialized_start=708
  _globals['_SETTINGSDISCUSSIONSETREQUEST']._serialized_end=834
  _globals['_SETTINGSDISCUSSIONSETRESPONSE']._serialized_start=836
  _globals['_SETTINGSDISCUSSIONSETRESPONSE']._serialized_end=963
# @@protoc_insertion_point(module_scope)
