# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/call_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/call_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import call_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_call__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5olvid/daemon/notification/v1/call_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a$olvid/daemon/datatypes/v1/call.proto\"N\n\'SubscribeToCallIncomingCallNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x9e\x02\n\x1c\x43\x61llIncomingCallNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12#\n\rdiscussion_id\x18\x02 \x01(\x04R\x0c\x64iscussionId\x12S\n\x0eparticipant_id\x18\x03 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\x12.\n\x13\x63\x61ller_display_name\x18\x04 \x01(\tR\x11\x63\x61llerDisplayName\x12+\n\x11participant_count\x18\x05 \x01(\rR\x10participantCount\"I\n\"SubscribeToCallRingingNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x97\x01\n\x17\x43\x61llRingingNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"J\n#SubscribeToCallAcceptedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x98\x01\n\x18\x43\x61llAcceptedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"J\n#SubscribeToCallDeclinedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x98\x01\n\x18\x43\x61llDeclinedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"F\n\x1fSubscribeToCallBusyNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x94\x01\n\x14\x43\x61llBusyNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"G\n SubscribeToCallEndedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"@\n\x15\x43\x61llEndedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifierB\xde\x01\n com.olvid.daemon.notification.v1B\x16\x43\x61llNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.call_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\026CallNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOCALLINCOMINGCALLNOTIFICATION']._serialized_start=125
  _globals['_SUBSCRIBETOCALLINCOMINGCALLNOTIFICATION']._serialized_end=203
  _globals['_CALLINCOMINGCALLNOTIFICATION']._serialized_start=206
  _globals['_CALLINCOMINGCALLNOTIFICATION']._serialized_end=492
  _globals['_SUBSCRIBETOCALLRINGINGNOTIFICATION']._serialized_start=494
  _globals['_SUBSCRIBETOCALLRINGINGNOTIFICATION']._serialized_end=567
  _globals['_CALLRINGINGNOTIFICATION']._serialized_start=570
  _globals['_CALLRINGINGNOTIFICATION']._serialized_end=721
  _globals['_SUBSCRIBETOCALLACCEPTEDNOTIFICATION']._serialized_start=723
  _globals['_SUBSCRIBETOCALLACCEPTEDNOTIFICATION']._serialized_end=797
  _globals['_CALLACCEPTEDNOTIFICATION']._serialized_start=800
  _globals['_CALLACCEPTEDNOTIFICATION']._serialized_end=952
  _globals['_SUBSCRIBETOCALLDECLINEDNOTIFICATION']._serialized_start=954
  _globals['_SUBSCRIBETOCALLDECLINEDNOTIFICATION']._serialized_end=1028
  _globals['_CALLDECLINEDNOTIFICATION']._serialized_start=1031
  _globals['_CALLDECLINEDNOTIFICATION']._serialized_end=1183
  _globals['_SUBSCRIBETOCALLBUSYNOTIFICATION']._serialized_start=1185
  _globals['_SUBSCRIBETOCALLBUSYNOTIFICATION']._serialized_end=1255
  _globals['_CALLBUSYNOTIFICATION']._serialized_start=1258
  _globals['_CALLBUSYNOTIFICATION']._serialized_end=1406
  _globals['_SUBSCRIBETOCALLENDEDNOTIFICATION']._serialized_start=1408
  _globals['_SUBSCRIBETOCALLENDEDNOTIFICATION']._serialized_end=1479
  _globals['_CALLENDEDNOTIFICATION']._serialized_start=1481
  _globals['_CALLENDEDNOTIFICATION']._serialized_end=1545
# @@protoc_insertion_point(module_scope)
