# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/message_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/message_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import message_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8olvid/daemon/notification/v1/message_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a\'olvid/daemon/datatypes/v1/message.proto\"\x9f\x01\n&SubscribeToMessageReceivedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"[\n\x1bMessageReceivedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\x9b\x01\n\"SubscribeToMessageSentNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"W\n\x17MessageSentNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe5\x01\n%SubscribeToMessageDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"Z\n\x1aMessageDeletedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe9\x01\n)SubscribeToMessageBodyUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\x83\x01\n\x1eMessageBodyUpdatedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12#\n\rprevious_body\x18\x02 \x01(\tR\x0cpreviousBody\"\xe6\x01\n&SubscribeToMessageUploadedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"[\n\x1bMessageUploadedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe7\x01\n\'SubscribeToMessageDeliveredNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\\\n\x1cMessageDeliveredNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe2\x01\n\"SubscribeToMessageReadNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"W\n\x17MessageReadNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xa7\x01\n.SubscribeToMessageLocationReceivedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"c\n#MessageLocationReceivedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xa3\x01\n*SubscribeToMessageLocationSentNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"_\n\x1fMessageLocationSentNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xab\x01\n2SubscribeToMessageLocationSharingStartNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"g\n\'MessageLocationSharingStartNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xf3\x01\n3SubscribeToMessageLocationSharingUpdateNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\xc1\x01\n(MessageLocationSharingUpdateNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12W\n\x11previous_location\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageLocationR\x10previousLocation\"\xf0\x01\n0SubscribeToMessageLocationSharingEndNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"e\n%MessageLocationSharingEndNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xd8\x02\n+SubscribeToMessageReactionAddedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filterB\x12\n\x10_reaction_filter\"\xa8\x01\n MessageReactionAddedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reaction\"\xf8\x03\n-SubscribeToMessageReactionUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12T\n\x0emessage_filter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\rmessageFilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x12h\n\x18previous_reaction_filter\x18\x05 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x03R\x16previousReactionFilter\x88\x01\x01\x42\x08\n\x06_countB\x11\n\x0f_message_filterB\x12\n\x10_reaction_filterB\x1b\n\x19_previous_reaction_filter\"\x83\x02\n\"MessageReactionUpdatedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reaction\x12W\n\x11previous_reaction\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x10previousReaction\"\xda\x02\n-SubscribeToMessageReactionRemovedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filterB\x12\n\x10_reaction_filter\"\xaa\x01\n\"MessageReactionRemovedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reactionB\xe1\x01\n com.olvid.daemon.notification.v1B\x19MessageNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.message_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\031MessageNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOMESSAGERECEIVEDNOTIFICATION']._serialized_start=132
  _globals['_SUBSCRIBETOMESSAGERECEIVEDNOTIFICATION']._serialized_end=291
  _globals['_MESSAGERECEIVEDNOTIFICATION']._serialized_start=293
  _globals['_MESSAGERECEIVEDNOTIFICATION']._serialized_end=384
  _globals['_SUBSCRIBETOMESSAGESENTNOTIFICATION']._serialized_start=387
  _globals['_SUBSCRIBETOMESSAGESENTNOTIFICATION']._serialized_end=542
  _globals['_MESSAGESENTNOTIFICATION']._serialized_start=544
  _globals['_MESSAGESENTNOTIFICATION']._serialized_end=631
  _globals['_SUBSCRIBETOMESSAGEDELETEDNOTIFICATION']._serialized_start=634
  _globals['_SUBSCRIBETOMESSAGEDELETEDNOTIFICATION']._serialized_end=863
  _globals['_MESSAGEDELETEDNOTIFICATION']._serialized_start=865
  _globals['_MESSAGEDELETEDNOTIFICATION']._serialized_end=955
  _globals['_SUBSCRIBETOMESSAGEBODYUPDATEDNOTIFICATION']._serialized_start=958
  _globals['_SUBSCRIBETOMESSAGEBODYUPDATEDNOTIFICATION']._serialized_end=1191
  _globals['_MESSAGEBODYUPDATEDNOTIFICATION']._serialized_start=1194
  _globals['_MESSAGEBODYUPDATEDNOTIFICATION']._serialized_end=1325
  _globals['_SUBSCRIBETOMESSAGEUPLOADEDNOTIFICATION']._serialized_start=1328
  _globals['_SUBSCRIBETOMESSAGEUPLOADEDNOTIFICATION']._serialized_end=1558
  _globals['_MESSAGEUPLOADEDNOTIFICATION']._serialized_start=1560
  _globals['_MESSAGEUPLOADEDNOTIFICATION']._serialized_end=1651
  _globals['_SUBSCRIBETOMESSAGEDELIVEREDNOTIFICATION']._serialized_start=1654
  _globals['_SUBSCRIBETOMESSAGEDELIVEREDNOTIFICATION']._serialized_end=1885
  _globals['_MESSAGEDELIVEREDNOTIFICATION']._serialized_start=1887
  _globals['_MESSAGEDELIVEREDNOTIFICATION']._serialized_end=1979
  _globals['_SUBSCRIBETOMESSAGEREADNOTIFICATION']._serialized_start=1982
  _globals['_SUBSCRIBETOMESSAGEREADNOTIFICATION']._serialized_end=2208
  _globals['_MESSAGEREADNOTIFICATION']._serialized_start=2210
  _globals['_MESSAGEREADNOTIFICATION']._serialized_end=2297
  _globals['_SUBSCRIBETOMESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_start=2300
  _globals['_SUBSCRIBETOMESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_end=2467
  _globals['_MESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_start=2469
  _globals['_MESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_end=2568
  _globals['_SUBSCRIBETOMESSAGELOCATIONSENTNOTIFICATION']._serialized_start=2571
  _globals['_SUBSCRIBETOMESSAGELOCATIONSENTNOTIFICATION']._serialized_end=2734
  _globals['_MESSAGELOCATIONSENTNOTIFICATION']._serialized_start=2736
  _globals['_MESSAGELOCATIONSENTNOTIFICATION']._serialized_end=2831
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_start=2834
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_end=3005
  _globals['_MESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_start=3007
  _globals['_MESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_end=3110
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_start=3113
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_end=3356
  _globals['_MESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_start=3359
  _globals['_MESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_end=3552
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_start=3555
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_end=3795
  _globals['_MESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_start=3797
  _globals['_MESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_end=3898
  _globals['_SUBSCRIBETOMESSAGEREACTIONADDEDNOTIFICATION']._serialized_start=3901
  _globals['_SUBSCRIBETOMESSAGEREACTIONADDEDNOTIFICATION']._serialized_end=4245
  _globals['_MESSAGEREACTIONADDEDNOTIFICATION']._serialized_start=4248
  _globals['_MESSAGEREACTIONADDEDNOTIFICATION']._serialized_end=4416
  _globals['_SUBSCRIBETOMESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_start=4419
  _globals['_SUBSCRIBETOMESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_end=4923
  _globals['_MESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_start=4926
  _globals['_MESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_end=5185
  _globals['_SUBSCRIBETOMESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_start=5188
  _globals['_SUBSCRIBETOMESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_end=5534
  _globals['_MESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_start=5537
  _globals['_MESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_end=5707
# @@protoc_insertion_point(module_scope)
