# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/backup.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&olvid/daemon/datatypes/v1/backup.proto\x12\x19olvid.daemon.datatypes.v1\x1a(olvid/daemon/datatypes/v1/settings.proto\"\x90\x07\n\x06\x42\x61\x63kup\x12P\n\x0c\x61\x64min_backup\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.Backup.AdminBackupR\x0b\x61\x64minBackup\x12X\n\x0fprofile_backups\x18\x02 \x03(\x0b\x32/.olvid.daemon.datatypes.v1.Backup.ProfileBackupR\x0eprofileBackups\x1ax\n\x0b\x41\x64minBackup\x12\x33\n\x16\x61\x64min_client_key_count\x18\x01 \x01(\x04R\x13\x61\x64minClientKeyCount\x12\x34\n\x16storage_elements_count\x18\x02 \x01(\x04R\x14storageElementsCount\x1a\xdf\x04\n\rProfileBackup\x12\x30\n\x14profile_display_name\x18\x01 \x01(\tR\x12profileDisplayName\x12\x34\n\x16\x61lready_exists_locally\x18\x02 \x01(\x08R\x14\x61lreadyExistsLocally\x12)\n\x10keycloak_managed\x18\x03 \x01(\x08R\x0fkeycloakManaged\x12V\n\tsnapshots\x18\x04 \x03(\x0b\x32\x38.olvid.daemon.datatypes.v1.Backup.ProfileBackup.SnapshotR\tsnapshots\x1a\xe2\x02\n\x08Snapshot\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12(\n\x10\x66rom_device_name\x18\x03 \x01(\tR\x0e\x66romDeviceName\x12#\n\rcontact_count\x18\x04 \x01(\x04R\x0c\x63ontactCount\x12\x1f\n\x0bgroup_count\x18\x05 \x01(\x04R\ngroupCount\x12(\n\x10\x63lient_key_count\x18\x06 \x01(\x04R\x0e\x63lientKeyCount\x12\x34\n\x16storage_elements_count\x18\x07 \x01(\x04R\x14storageElementsCount\x12X\n\x11identity_settings\x18\x08 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettingsB\xc4\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0b\x42\x61\x63kupProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\013BackupProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_BACKUP']._serialized_start=112
  _globals['_BACKUP']._serialized_end=1024
  _globals['_BACKUP_ADMINBACKUP']._serialized_start=294
  _globals['_BACKUP_ADMINBACKUP']._serialized_end=414
  _globals['_BACKUP_PROFILEBACKUP']._serialized_start=417
  _globals['_BACKUP_PROFILEBACKUP']._serialized_end=1024
  _globals['_BACKUP_PROFILEBACKUP_SNAPSHOT']._serialized_start=670
  _globals['_BACKUP_PROFILEBACKUP_SNAPSHOT']._serialized_end=1024
# @@protoc_insertion_point(module_scope)
