####
# WARNING: DO NOT EDIT: this code is automatically generated, see overlay_generator/generate_listeners_module.py
####

from enum import Enum


class NOTIFICATIONS(Enum):
	# InvitationNotificationService
	INVITATION_RECEIVED = 0
	INVITATION_SENT = 1
	INVITATION_DELETED = 2
	INVITATION_UPDATED = 3

	# ContactNotificationService
	CONTACT_NEW = 4
	CONTACT_DELETED = 5
	CONTACT_DETAILS_UPDATED = 6
	CONTACT_PHOTO_UPDATED = 7

	# GroupNotificationService
	GROUP_NEW = 8
	GROUP_DELETED = 9
	GROUP_NAME_UPDATED = 10
	GROUP_PHOTO_UPDATED = 11
	GROUP_DESCRIPTION_UPDATED = 12
	GROUP_PENDING_MEMBER_ADDED = 13
	GROUP_PENDING_MEMBER_REMOVED = 14
	GROUP_MEMBER_JOINED = 15
	GROUP_MEMBER_LEFT = 16
	GROUP_OWN_PERMISSIONS_UPDATED = 17
	GROUP_MEMBER_PERMISSIONS_UPDATED = 18

	# DiscussionNotificationService
	DISCUSSION_NEW = 19
	DISCUSSION_LOCKED = 20
	DISCUSSION_TITLE_UPDATED = 21
	DISCUSSION_SETTINGS_UPDATED = 22

	# MessageNotificationService
	MESSAGE_RECEIVED = 23
	MESSAGE_SENT = 24
	MESSAGE_DELETED = 25
	MESSAGE_BODY_UPDATED = 26
	MESSAGE_UPLOADED = 27
	MESSAGE_DELIVERED = 28
	MESSAGE_READ = 29
	MESSAGE_LOCATION_RECEIVED = 30
	MESSAGE_LOCATION_SENT = 31
	MESSAGE_LOCATION_SHARING_START = 32
	MESSAGE_LOCATION_SHARING_UPDATE = 33
	MESSAGE_LOCATION_SHARING_END = 34
	MESSAGE_REACTION_ADDED = 35
	MESSAGE_REACTION_UPDATED = 36
	MESSAGE_REACTION_REMOVED = 37

	# AttachmentNotificationService
	ATTACHMENT_RECEIVED = 38
	ATTACHMENT_UPLOADED = 39

	# CallNotificationService
	CALL_INCOMING_CALL = 40
	CALL_RINGING = 41
	CALL_ACCEPTED = 42
	CALL_DECLINED = 43
	CALL_BUSY = 44
	CALL_ENDED = 45
		
