# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/discussion_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/discussion_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import discussion_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_discussion__pb2
from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;olvid/daemon/notification/v1/discussion_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a*olvid/daemon/datatypes/v1/discussion.proto\x1a(olvid/daemon/datatypes/v1/settings.proto\"\xa0\x01\n$SubscribeToDiscussionNewNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"b\n\x19\x44iscussionNewNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\"\xca\x01\n\'SubscribeToDiscussionLockedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"e\n\x1c\x44iscussionLockedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\"\xd0\x01\n-SubscribeToDiscussionTitleUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"\x92\x01\n\"DiscussionTitleUpdatedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\x12%\n\x0eprevious_title\x18\x02 \x01(\tR\rpreviousTitle\"\xd3\x01\n0SubscribeToDiscussionSettingsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"\x9c\x02\n%DiscussionSettingsUpdatedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\x12P\n\x0cnew_settings\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x0bnewSettings\x12Z\n\x11previous_settings\x18\x03 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x10previousSettingsB\xe4\x01\n com.olvid.daemon.notification.v1B\x1c\x44iscussionNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.discussion_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\034DiscussionNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETODISCUSSIONNEWNOTIFICATION']._serialized_start=180
  _globals['_SUBSCRIBETODISCUSSIONNEWNOTIFICATION']._serialized_end=340
  _globals['_DISCUSSIONNEWNOTIFICATION']._serialized_start=342
  _globals['_DISCUSSIONNEWNOTIFICATION']._serialized_end=440
  _globals['_SUBSCRIBETODISCUSSIONLOCKEDNOTIFICATION']._serialized_start=443
  _globals['_SUBSCRIBETODISCUSSIONLOCKEDNOTIFICATION']._serialized_end=645
  _globals['_DISCUSSIONLOCKEDNOTIFICATION']._serialized_start=647
  _globals['_DISCUSSIONLOCKEDNOTIFICATION']._serialized_end=748
  _globals['_SUBSCRIBETODISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_start=751
  _globals['_SUBSCRIBETODISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_end=959
  _globals['_DISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_start=962
  _globals['_DISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_end=1108
  _globals['_SUBSCRIBETODISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_start=1111
  _globals['_SUBSCRIBETODISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_end=1322
  _globals['_DISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_start=1325
  _globals['_DISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_end=1609
# @@protoc_insertion_point(module_scope)
