# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/services/v1/admin_service.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/services/v1/admin_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.admin.v1 import backup_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2
from .....olvid.daemon.admin.v1 import client_key_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2
from .....olvid.daemon.admin.v1 import identity_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,olvid/daemon/services/v1/admin_service.proto\x12\x18olvid.daemon.services.v1\x1a(olvid/daemon/admin/v1/backup_admin.proto\x1a,olvid/daemon/admin/v1/client_key_admin.proto\x1a*olvid/daemon/admin/v1/identity_admin.proto2\xd1\x03\n\x15\x43lientKeyAdminService\x12n\n\rClientKeyList\x12+.olvid.daemon.admin.v1.ClientKeyListRequest\x1a,.olvid.daemon.admin.v1.ClientKeyListResponse\"\x00\x30\x01\x12i\n\x0c\x43lientKeyGet\x12*.olvid.daemon.admin.v1.ClientKeyGetRequest\x1a+.olvid.daemon.admin.v1.ClientKeyGetResponse\"\x00\x12i\n\x0c\x43lientKeyNew\x12*.olvid.daemon.admin.v1.ClientKeyNewRequest\x1a+.olvid.daemon.admin.v1.ClientKeyNewResponse\"\x00\x12r\n\x0f\x43lientKeyDelete\x12-.olvid.daemon.admin.v1.ClientKeyDeleteRequest\x1a..olvid.daemon.admin.v1.ClientKeyDeleteResponse\"\x00\x32\xb0\x08\n\x14IdentityAdminService\x12k\n\x0cIdentityList\x12*.olvid.daemon.admin.v1.IdentityListRequest\x1a+.olvid.daemon.admin.v1.IdentityListResponse\"\x00\x30\x01\x12u\n\x10IdentityAdminGet\x12..olvid.daemon.admin.v1.IdentityAdminGetRequest\x1a/.olvid.daemon.admin.v1.IdentityAdminGetResponse\"\x00\x12\xa2\x01\n\x1fIdentityAdminGetBytesIdentifier\x12=.olvid.daemon.admin.v1.IdentityAdminGetBytesIdentifierRequest\x1a>.olvid.daemon.admin.v1.IdentityAdminGetBytesIdentifierResponse\"\x00\x12\x9f\x01\n\x1eIdentityAdminGetInvitationLink\x12<.olvid.daemon.admin.v1.IdentityAdminGetInvitationLinkRequest\x1a=.olvid.daemon.admin.v1.IdentityAdminGetInvitationLinkResponse\"\x00\x12\x93\x01\n\x1aIdentityAdminDownloadPhoto\x12\x38.olvid.daemon.admin.v1.IdentityAdminDownloadPhotoRequest\x1a\x39.olvid.daemon.admin.v1.IdentityAdminDownloadPhotoResponse\"\x00\x12o\n\x0eIdentityDelete\x12,.olvid.daemon.admin.v1.IdentityDeleteRequest\x1a-.olvid.daemon.admin.v1.IdentityDeleteResponse\"\x00\x12\x66\n\x0bIdentityNew\x12).olvid.daemon.admin.v1.IdentityNewRequest\x1a*.olvid.daemon.admin.v1.IdentityNewResponse\"\x00\x12~\n\x13IdentityKeycloakNew\x12\x31.olvid.daemon.admin.v1.IdentityKeycloakNewRequest\x1a\x32.olvid.daemon.admin.v1.IdentityKeycloakNewResponse\"\x00\x32\xe0\x06\n\x12\x42\x61\x63kupAdminService\x12i\n\x0c\x42\x61\x63kupKeyGet\x12*.olvid.daemon.admin.v1.BackupKeyGetRequest\x1a+.olvid.daemon.admin.v1.BackupKeyGetResponse\"\x00\x12o\n\x0e\x42\x61\x63kupKeyRenew\x12,.olvid.daemon.admin.v1.BackupKeyRenewRequest\x1a-.olvid.daemon.admin.v1.BackupKeyRenewResponse\"\x00\x12`\n\tBackupGet\x12\'.olvid.daemon.admin.v1.BackupGetRequest\x1a(.olvid.daemon.admin.v1.BackupGetResponse\"\x00\x12`\n\tBackupNow\x12\'.olvid.daemon.admin.v1.BackupNowRequest\x1a(.olvid.daemon.admin.v1.BackupNowResponse\"\x00\x12~\n\x13\x42\x61\x63kupRestoreDaemon\x12\x31.olvid.daemon.admin.v1.BackupRestoreDaemonRequest\x1a\x32.olvid.daemon.admin.v1.BackupRestoreDaemonResponse\"\x00\x12\x8d\x01\n\x18\x42\x61\x63kupRestoreAdminBackup\x12\x36.olvid.daemon.admin.v1.BackupRestoreAdminBackupRequest\x1a\x37.olvid.daemon.admin.v1.BackupRestoreAdminBackupResponse\"\x00\x12\x99\x01\n\x1c\x42\x61\x63kupRestoreProfileSnapshot\x12:.olvid.daemon.admin.v1.BackupRestoreProfileSnapshotRequest\x1a;.olvid.daemon.admin.v1.BackupRestoreProfileSnapshotResponse\"\x00\x42\xc5\x01\n\x1c\x63om.olvid.daemon.services.v1B\x11\x41\x64minServiceProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODS\xaa\x02\x18Olvid.Daemon.Services.V1\xca\x02\x18Olvid\\Daemon\\Services\\V1\xe2\x02$Olvid\\Daemon\\Services\\V1\\GPBMetadata\xea\x02\x1bOlvid::Daemon::Services::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.services.v1.admin_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.olvid.daemon.services.v1B\021AdminServiceProtoP\001Z\017olvid.io/daemon\242\002\003ODS\252\002\030Olvid.Daemon.Services.V1\312\002\030Olvid\\Daemon\\Services\\V1\342\002$Olvid\\Daemon\\Services\\V1\\GPBMetadata\352\002\033Olvid::Daemon::Services::V1'
  _globals['_CLIENTKEYADMINSERVICE']._serialized_start=207
  _globals['_CLIENTKEYADMINSERVICE']._serialized_end=672
  _globals['_IDENTITYADMINSERVICE']._serialized_start=675
  _globals['_IDENTITYADMINSERVICE']._serialized_end=1747
  _globals['_BACKUPADMINSERVICE']._serialized_start=1750
  _globals['_BACKUPADMINSERVICE']._serialized_end=2614
# @@protoc_insertion_point(module_scope)
