# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/tool_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/tool_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+olvid/daemon/command/v1/tool_commands.proto\x12\x17olvid.daemon.command.v1\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x16\n\x14\x44\x61\x65monVersionRequest\"1\n\x15\x44\x61\x65monVersionResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\"\x1b\n\x19\x41uthenticationTestRequest\"\x1c\n\x1a\x41uthenticationTestResponse\" \n\x1e\x41uthenticationAdminTestRequest\"!\n\x1f\x41uthenticationAdminTestResponseB\xc0\x01\n\x1b\x63om.olvid.daemon.command.v1B\x11ToolCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.tool_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\021ToolCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_PINGREQUEST']._serialized_start=72
  _globals['_PINGREQUEST']._serialized_end=85
  _globals['_PINGRESPONSE']._serialized_start=87
  _globals['_PINGRESPONSE']._serialized_end=101
  _globals['_DAEMONVERSIONREQUEST']._serialized_start=103
  _globals['_DAEMONVERSIONREQUEST']._serialized_end=125
  _globals['_DAEMONVERSIONRESPONSE']._serialized_start=127
  _globals['_DAEMONVERSIONRESPONSE']._serialized_end=176
  _globals['_AUTHENTICATIONTESTREQUEST']._serialized_start=178
  _globals['_AUTHENTICATIONTESTREQUEST']._serialized_end=205
  _globals['_AUTHENTICATIONTESTRESPONSE']._serialized_start=207
  _globals['_AUTHENTICATIONTESTRESPONSE']._serialized_end=235
  _globals['_AUTHENTICATIONADMINTESTREQUEST']._serialized_start=237
  _globals['_AUTHENTICATIONADMINTESTREQUEST']._serialized_end=269
  _globals['_AUTHENTICATIONADMINTESTRESPONSE']._serialized_start=271
  _globals['_AUTHENTICATIONADMINTESTRESPONSE']._serialized_end=304
# @@protoc_insertion_point(module_scope)
