# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/call_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/call_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+olvid/daemon/command/v1/call_commands.proto\x12\x17olvid.daemon.command.v1\"E\n\x1e\x43\x61llStartDiscussionCallRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\"J\n\x1f\x43\x61llStartDiscussionCallResponse\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\"y\n\x1a\x43\x61llStartCustomCallRequest\x12\x1f\n\x0b\x63ontact_ids\x18\x01 \x03(\x04R\ncontactIds\x12(\n\rdiscussion_id\x18\x02 \x01(\x04H\x00R\x0c\x64iscussionId\x88\x01\x01\x42\x10\n\x0e_discussion_id\"F\n\x1b\x43\x61llStartCustomCallResponse\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifierB\xc0\x01\n\x1b\x63om.olvid.daemon.command.v1B\x11\x43\x61llCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.call_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\021CallCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_CALLSTARTDISCUSSIONCALLREQUEST']._serialized_start=72
  _globals['_CALLSTARTDISCUSSIONCALLREQUEST']._serialized_end=141
  _globals['_CALLSTARTDISCUSSIONCALLRESPONSE']._serialized_start=143
  _globals['_CALLSTARTDISCUSSIONCALLRESPONSE']._serialized_end=217
  _globals['_CALLSTARTCUSTOMCALLREQUEST']._serialized_start=219
  _globals['_CALLSTARTCUSTOMCALLREQUEST']._serialized_end=340
  _globals['_CALLSTARTCUSTOMCALLRESPONSE']._serialized_start=342
  _globals['_CALLSTARTCUSTOMCALLRESPONSE']._serialized_end=412
# @@protoc_insertion_point(module_scope)
