# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/contact_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/contact_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import contact_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_contact__pb2
from .....olvid.daemon.datatypes.v1 import invitation_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.olvid/daemon/command/v1/contact_commands.proto\x12\x17olvid.daemon.command.v1\x1a\'olvid/daemon/datatypes/v1/contact.proto\x1a*olvid/daemon/datatypes/v1/invitation.proto\"f\n\x12\x43ontactListRequest\x12\x45\n\x06\x66ilter\x18\x01 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.ContactFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"U\n\x13\x43ontactListResponse\x12>\n\x08\x63ontacts\x18\x01 \x03(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x08\x63ontacts\"2\n\x11\x43ontactGetRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"R\n\x12\x43ontactGetResponse\x12<\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x07\x63ontact\"A\n ContactGetBytesIdentifierRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"C\n!ContactGetBytesIdentifierResponse\x12\x1e\n\nidentifier\x18\x01 \x01(\x0cR\nidentifier\"@\n\x1f\x43ontactGetInvitationLinkRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"K\n ContactGetInvitationLinkResponse\x12\'\n\x0finvitation_link\x18\x01 \x01(\tR\x0einvitationLink\"5\n\x14\x43ontactDeleteRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"\x17\n\x15\x43ontactDeleteResponse\"r\n\x1a\x43ontactIntroductionRequest\x12(\n\x10\x66irst_contact_id\x18\x01 \x01(\x04R\x0e\x66irstContactId\x12*\n\x11second_contact_id\x18\x02 \x01(\x04R\x0fsecondContactId\"\x1d\n\x1b\x43ontactIntroductionResponse\"I\n(ContactInviteToOneToOneDiscussionRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"r\n)ContactInviteToOneToOneDiscussionResponse\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"J\n)ContactDowngradeOneToOneDiscussionRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\",\n*ContactDowngradeOneToOneDiscussionResponse\"<\n\x1b\x43ontactDownloadPhotoRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"4\n\x1c\x43ontactDownloadPhotoResponse\x12\x14\n\x05photo\x18\x01 \x01(\x0cR\x05photo\"?\n\x1e\x43ontactRecreateChannelsRequest\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\"!\n\x1f\x43ontactRecreateChannelsResponseB\xc3\x01\n\x1b\x63om.olvid.daemon.command.v1B\x14\x43ontactCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.contact_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\024ContactCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_CONTACTLISTREQUEST']._serialized_start=160
  _globals['_CONTACTLISTREQUEST']._serialized_end=262
  _globals['_CONTACTLISTRESPONSE']._serialized_start=264
  _globals['_CONTACTLISTRESPONSE']._serialized_end=349
  _globals['_CONTACTGETREQUEST']._serialized_start=351
  _globals['_CONTACTGETREQUEST']._serialized_end=401
  _globals['_CONTACTGETRESPONSE']._serialized_start=403
  _globals['_CONTACTGETRESPONSE']._serialized_end=485
  _globals['_CONTACTGETBYTESIDENTIFIERREQUEST']._serialized_start=487
  _globals['_CONTACTGETBYTESIDENTIFIERREQUEST']._serialized_end=552
  _globals['_CONTACTGETBYTESIDENTIFIERRESPONSE']._serialized_start=554
  _globals['_CONTACTGETBYTESIDENTIFIERRESPONSE']._serialized_end=621
  _globals['_CONTACTGETINVITATIONLINKREQUEST']._serialized_start=623
  _globals['_CONTACTGETINVITATIONLINKREQUEST']._serialized_end=687
  _globals['_CONTACTGETINVITATIONLINKRESPONSE']._serialized_start=689
  _globals['_CONTACTGETINVITATIONLINKRESPONSE']._serialized_end=764
  _globals['_CONTACTDELETEREQUEST']._serialized_start=766
  _globals['_CONTACTDELETEREQUEST']._serialized_end=819
  _globals['_CONTACTDELETERESPONSE']._serialized_start=821
  _globals['_CONTACTDELETERESPONSE']._serialized_end=844
  _globals['_CONTACTINTRODUCTIONREQUEST']._serialized_start=846
  _globals['_CONTACTINTRODUCTIONREQUEST']._serialized_end=960
  _globals['_CONTACTINTRODUCTIONRESPONSE']._serialized_start=962
  _globals['_CONTACTINTRODUCTIONRESPONSE']._serialized_end=991
  _globals['_CONTACTINVITETOONETOONEDISCUSSIONREQUEST']._serialized_start=993
  _globals['_CONTACTINVITETOONETOONEDISCUSSIONREQUEST']._serialized_end=1066
  _globals['_CONTACTINVITETOONETOONEDISCUSSIONRESPONSE']._serialized_start=1068
  _globals['_CONTACTINVITETOONETOONEDISCUSSIONRESPONSE']._serialized_end=1182
  _globals['_CONTACTDOWNGRADEONETOONEDISCUSSIONREQUEST']._serialized_start=1184
  _globals['_CONTACTDOWNGRADEONETOONEDISCUSSIONREQUEST']._serialized_end=1258
  _globals['_CONTACTDOWNGRADEONETOONEDISCUSSIONRESPONSE']._serialized_start=1260
  _globals['_CONTACTDOWNGRADEONETOONEDISCUSSIONRESPONSE']._serialized_end=1304
  _globals['_CONTACTDOWNLOADPHOTOREQUEST']._serialized_start=1306
  _globals['_CONTACTDOWNLOADPHOTOREQUEST']._serialized_end=1366
  _globals['_CONTACTDOWNLOADPHOTORESPONSE']._serialized_start=1368
  _globals['_CONTACTDOWNLOADPHOTORESPONSE']._serialized_end=1420
  _globals['_CONTACTRECREATECHANNELSREQUEST']._serialized_start=1422
  _globals['_CONTACTRECREATECHANNELSREQUEST']._serialized_end=1485
  _globals['_CONTACTRECREATECHANNELSRESPONSE']._serialized_start=1487
  _globals['_CONTACTRECREATECHANNELSRESPONSE']._serialized_end=1520
# @@protoc_insertion_point(module_scope)
