# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/group_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/group_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import group_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6olvid/daemon/notification/v1/group_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a%olvid/daemon/datatypes/v1/group.proto\"\xa7\x01\n\x1fSubscribeToGroupNewNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12N\n\x0cgroup_filter\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"N\n\x14GroupNewNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xc8\x01\n#SubscribeToGroupDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"R\n\x18GroupDeletedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\x9c\x02\n\'SubscribeToGroupNameUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x35\n\x14previous_name_search\x18\x04 \x01(\tH\x02R\x12previousNameSearch\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x17\n\x15_previous_name_search\"{\n\x1cGroupNameUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12#\n\rprevious_name\x18\x02 \x01(\tR\x0cpreviousName\"\xcd\x01\n(SubscribeToGroupPhotoUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"W\n\x1dGroupPhotoUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xb8\x02\n.SubscribeToGroupDescriptionUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x43\n\x1bprevious_description_search\x18\x04 \x01(\tH\x02R\x19previousDescriptionSearch\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x1e\n\x1c_previous_description_search\"\x90\x01\n#GroupDescriptionUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12\x31\n\x14previous_description\x18\x02 \x01(\tR\x13previousDescription\"\xdb\x02\n.SubscribeToGroupPendingMemberAddedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12l\n\x15pending_member_filter\x18\x04 \x01(\x0b\x32\x33.olvid.daemon.datatypes.v1.PendingGroupMemberFilterH\x02R\x13pendingMemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x18\n\x16_pending_member_filter\"\xb3\x01\n#GroupPendingMemberAddedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"\xdd\x02\n0SubscribeToGroupPendingMemberRemovedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12l\n\x15pending_member_filter\x18\x04 \x01(\x0b\x32\x33.olvid.daemon.datatypes.v1.PendingGroupMemberFilterH\x02R\x13pendingMemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x18\n\x16_pending_member_filter\"\xb5\x01\n%GroupPendingMemberRemovedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"\xb7\x02\n(SubscribeToGroupMemberJoinedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filter\"\x97\x01\n\x1dGroupMemberJoinedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"\xb5\x02\n&SubscribeToGroupMemberLeftNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filter\"\x95\x01\n\x1bGroupMemberLeftNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"\xea\x03\n1SubscribeToGroupOwnPermissionsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x64\n\x12permissions_filter\x18\x04 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x02R\x11permissionsFilter\x88\x01\x01\x12u\n\x1bprevious_permissions_filter\x18\x05 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x03R\x19previousPermissionsFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x15\n\x13_permissions_filterB\x1e\n\x1c_previous_permissions_filter\"\x9b\x02\n&GroupOwnPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12S\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0bpermissions\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissions\"\xd3\x03\n4SubscribeToGroupMemberPermissionsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x12o\n\x1aprevious_permission_filter\x18\x05 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x03R\x18previousPermissionFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filterB\x1d\n\x1b_previous_permission_filter\"\x89\x02\n)GroupMemberPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissionsB\xdf\x01\n com.olvid.daemon.notification.v1B\x17GroupNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.group_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\027GroupNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_start=128
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_end=295
  _globals['_GROUPNEWNOTIFICATION']._serialized_start=297
  _globals['_GROUPNEWNOTIFICATION']._serialized_end=375
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_start=378
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_end=578
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_start=580
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_end=662
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_start=665
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_end=949
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_start=951
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_end=1074
  _globals['_SUBSCRIBETOGROUPPHOTOUPDATEDNOTIFICATION']._serialized_start=1077
  _globals['_SUBSCRIBETOGROUPPHOTOUPDATEDNOTIFICATION']._serialized_end=1282
  _globals['_GROUPPHOTOUPDATEDNOTIFICATION']._serialized_start=1284
  _globals['_GROUPPHOTOUPDATEDNOTIFICATION']._serialized_end=1371
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=1374
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=1686
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=1689
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=1833
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=1836
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=2183
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=2186
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=2365
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=2368
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=2717
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=2720
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=2901
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_start=2904
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_end=3215
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_start=3218
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_end=3369
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_start=3372
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_end=3681
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_start=3684
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_end=3833
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=3836
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=4326
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=4329
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=4612
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=4615
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=5082
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=5085
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=5350
# @@protoc_insertion_point(module_scope)
