# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/keycloak.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/keycloak.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(olvid/daemon/datatypes/v1/keycloak.proto\x12\x19olvid.daemon.datatypes.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\"\xcb\x01\n\x0cKeycloakUser\x12\x1f\n\x0bkeycloak_id\x18\x01 \x01(\tR\nkeycloakId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x44\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\x07\x64\x65tails\x12\"\n\ncontact_id\x18\x04 \x01(\x04H\x00R\tcontactId\x88\x01\x01\x42\r\n\x0b_contact_id\"\xf6\x02\n\x12KeycloakUserFilter\x12T\n\x07\x63ontact\x18\x01 \x01(\x0e\x32\x35.olvid.daemon.datatypes.v1.KeycloakUserFilter.ContactH\x00R\x07\x63ontact\x88\x01\x01\x12\x33\n\x13\x64isplay_name_search\x18\x02 \x01(\tH\x01R\x11\x64isplayNameSearch\x88\x01\x01\x12V\n\x0e\x64\x65tails_search\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsH\x02R\rdetailsSearch\x88\x01\x01\"F\n\x07\x43ontact\x12\x17\n\x13\x43ONTACT_UNSPECIFIED\x10\x00\x12\x0e\n\nCONTACT_IS\x10\x01\x12\x12\n\x0e\x43ONTACT_IS_NOT\x10\x02\x42\n\n\x08_contactB\x16\n\x14_display_name_searchB\x11\n\x0f_details_search\"\x7f\n\x16KeycloakApiCredentials\x12\x1d\n\nserver_url\x18\x01 \x01(\tR\tserverUrl\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12*\n\x11\x64irect_auth_token\x18\x03 \x01(\tR\x0f\x64irectAuthTokenB\xc6\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\rKeycloakProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.keycloak_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\rKeycloakProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_KEYCLOAKUSER']._serialized_start=114
  _globals['_KEYCLOAKUSER']._serialized_end=317
  _globals['_KEYCLOAKUSERFILTER']._serialized_start=320
  _globals['_KEYCLOAKUSERFILTER']._serialized_end=694
  _globals['_KEYCLOAKUSERFILTER_CONTACT']._serialized_start=569
  _globals['_KEYCLOAKUSERFILTER_CONTACT']._serialized_end=639
  _globals['_KEYCLOAKAPICREDENTIALS']._serialized_start=696
  _globals['_KEYCLOAKAPICREDENTIALS']._serialized_end=823
# @@protoc_insertion_point(module_scope)
