# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from .....olvid.daemon.admin.v1 import backup_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2
from .....olvid.daemon.admin.v1 import client_key_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2
from .....olvid.daemon.admin.v1 import identity_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2


class ClientKeyAdminServiceStub(object):
    """ClientKey
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClientKeyList = channel.unary_stream(
                '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyList',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListResponse.FromString,
                _registered_method=True)
        self.ClientKeyGet = channel.unary_unary(
                '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyGet',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetResponse.FromString,
                _registered_method=True)
        self.ClientKeyNew = channel.unary_unary(
                '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyNew',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewResponse.FromString,
                _registered_method=True)
        self.ClientKeyDelete = channel.unary_unary(
                '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyDelete',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteResponse.FromString,
                _registered_method=True)


class ClientKeyAdminServiceServicer(object):
    """ClientKey
    """

    def ClientKeyList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientKeyGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientKeyNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientKeyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientKeyAdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClientKeyList': grpc.unary_stream_rpc_method_handler(
                    servicer.ClientKeyList,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListResponse.SerializeToString,
            ),
            'ClientKeyGet': grpc.unary_unary_rpc_method_handler(
                    servicer.ClientKeyGet,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetResponse.SerializeToString,
            ),
            'ClientKeyNew': grpc.unary_unary_rpc_method_handler(
                    servicer.ClientKeyNew,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewResponse.SerializeToString,
            ),
            'ClientKeyDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.ClientKeyDelete,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.ClientKeyAdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.ClientKeyAdminService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ClientKeyAdminService(object):
    """ClientKey
    """

    @staticmethod
    def ClientKeyList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyList',
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClientKeyGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyGet',
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClientKeyNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyNew',
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyNewResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClientKeyDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.ClientKeyAdminService/ClientKeyDelete',
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2.ClientKeyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class IdentityAdminServiceStub(object):
    """Identity
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IdentityList = channel.unary_stream(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityList',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListResponse.FromString,
                _registered_method=True)
        self.IdentityAdminGet = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGet',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetResponse.FromString,
                _registered_method=True)
        self.IdentityAdminGetBytesIdentifier = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGetBytesIdentifier',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierResponse.FromString,
                _registered_method=True)
        self.IdentityAdminGetInvitationLink = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGetInvitationLink',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkResponse.FromString,
                _registered_method=True)
        self.IdentityAdminDownloadPhoto = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminDownloadPhoto',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoResponse.FromString,
                _registered_method=True)
        self.IdentityDelete = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityDelete',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteResponse.FromString,
                _registered_method=True)
        self.IdentityNew = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityNew',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewResponse.FromString,
                _registered_method=True)
        self.IdentityKeycloakNew = channel.unary_unary(
                '/olvid.daemon.services.v1.IdentityAdminService/IdentityKeycloakNew',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewResponse.FromString,
                _registered_method=True)


class IdentityAdminServiceServicer(object):
    """Identity
    """

    def IdentityList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityAdminGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityAdminGetBytesIdentifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityAdminGetInvitationLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityAdminDownloadPhoto(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IdentityKeycloakNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IdentityAdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IdentityList': grpc.unary_stream_rpc_method_handler(
                    servicer.IdentityList,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListResponse.SerializeToString,
            ),
            'IdentityAdminGet': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityAdminGet,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetResponse.SerializeToString,
            ),
            'IdentityAdminGetBytesIdentifier': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityAdminGetBytesIdentifier,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierResponse.SerializeToString,
            ),
            'IdentityAdminGetInvitationLink': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityAdminGetInvitationLink,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkResponse.SerializeToString,
            ),
            'IdentityAdminDownloadPhoto': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityAdminDownloadPhoto,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoResponse.SerializeToString,
            ),
            'IdentityDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityDelete,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteResponse.SerializeToString,
            ),
            'IdentityNew': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityNew,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewResponse.SerializeToString,
            ),
            'IdentityKeycloakNew': grpc.unary_unary_rpc_method_handler(
                    servicer.IdentityKeycloakNew,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.IdentityAdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.IdentityAdminService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IdentityAdminService(object):
    """Identity
    """

    @staticmethod
    def IdentityList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityList',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityAdminGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGet',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityAdminGetBytesIdentifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGetBytesIdentifier',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetBytesIdentifierResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityAdminGetInvitationLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminGetInvitationLink',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminGetInvitationLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityAdminDownloadPhoto(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityAdminDownloadPhoto',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityAdminDownloadPhotoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityDelete',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityNew',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityNewResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IdentityKeycloakNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.IdentityAdminService/IdentityKeycloakNew',
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2.IdentityKeycloakNewResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class BackupAdminServiceStub(object):
    """Backup
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BackupKeyGet = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupKeyGet',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetResponse.FromString,
                _registered_method=True)
        self.BackupKeyRenew = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupKeyRenew',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewResponse.FromString,
                _registered_method=True)
        self.BackupGet = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupGet',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetResponse.FromString,
                _registered_method=True)
        self.BackupNow = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupNow',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowResponse.FromString,
                _registered_method=True)
        self.BackupRestoreDaemon = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreDaemon',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonResponse.FromString,
                _registered_method=True)
        self.BackupRestoreAdminBackup = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreAdminBackup',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupResponse.FromString,
                _registered_method=True)
        self.BackupRestoreProfileSnapshot = channel.unary_unary(
                '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreProfileSnapshot',
                request_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotRequest.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotResponse.FromString,
                _registered_method=True)


class BackupAdminServiceServicer(object):
    """Backup
    """

    def BackupKeyGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupKeyRenew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupNow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupRestoreDaemon(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupRestoreAdminBackup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupRestoreProfileSnapshot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BackupAdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BackupKeyGet': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupKeyGet,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetResponse.SerializeToString,
            ),
            'BackupKeyRenew': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupKeyRenew,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewResponse.SerializeToString,
            ),
            'BackupGet': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupGet,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetResponse.SerializeToString,
            ),
            'BackupNow': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupNow,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowResponse.SerializeToString,
            ),
            'BackupRestoreDaemon': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupRestoreDaemon,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonResponse.SerializeToString,
            ),
            'BackupRestoreAdminBackup': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupRestoreAdminBackup,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupResponse.SerializeToString,
            ),
            'BackupRestoreProfileSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupRestoreProfileSnapshot,
                    request_deserializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotRequest.FromString,
                    response_serializer=olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.BackupAdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.BackupAdminService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class BackupAdminService(object):
    """Backup
    """

    @staticmethod
    def BackupKeyGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupKeyGet',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupKeyRenew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupKeyRenew',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupKeyRenewResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupGet',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupNow',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupNowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupRestoreDaemon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreDaemon',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreDaemonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupRestoreAdminBackup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreAdminBackup',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreAdminBackupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BackupRestoreProfileSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/olvid.daemon.services.v1.BackupAdminService/BackupRestoreProfileSnapshot',
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotRequest.SerializeToString,
            olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2.BackupRestoreProfileSnapshotResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
