# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/invitation_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/invitation_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import invitation_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1olvid/daemon/command/v1/invitation_commands.proto\x12\x17olvid.daemon.command.v1\x1a*olvid/daemon/datatypes/v1/invitation.proto\"l\n\x15InvitationListRequest\x12H\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.InvitationFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"a\n\x16InvitationListResponse\x12G\n\x0binvitations\x18\x01 \x03(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\x0binvitations\";\n\x14InvitationGetRequest\x12#\n\rinvitation_id\x18\x01 \x01(\x04R\x0cinvitationId\"^\n\x15InvitationGetResponse\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"=\n\x14InvitationNewRequest\x12%\n\x0einvitation_url\x18\x01 \x01(\tR\rinvitationUrl\"^\n\x15InvitationNewResponse\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\">\n\x17InvitationAcceptRequest\x12#\n\rinvitation_id\x18\x01 \x01(\x04R\x0cinvitationId\"\x1a\n\x18InvitationAcceptResponse\"?\n\x18InvitationDeclineRequest\x12#\n\rinvitation_id\x18\x01 \x01(\x04R\x0cinvitationId\"\x1b\n\x19InvitationDeclineResponse\"M\n\x14InvitationSasRequest\x12#\n\rinvitation_id\x18\x01 \x01(\x04R\x0cinvitationId\x12\x10\n\x03sas\x18\x02 \x01(\tR\x03sas\"\x17\n\x15InvitationSasResponse\">\n\x17InvitationDeleteRequest\x12#\n\rinvitation_id\x18\x01 \x01(\x04R\x0cinvitationId\"\x1a\n\x18InvitationDeleteResponseB\xc6\x01\n\x1b\x63om.olvid.daemon.command.v1B\x17InvitationCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.invitation_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\027InvitationCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_INVITATIONLISTREQUEST']._serialized_start=122
  _globals['_INVITATIONLISTREQUEST']._serialized_end=230
  _globals['_INVITATIONLISTRESPONSE']._serialized_start=232
  _globals['_INVITATIONLISTRESPONSE']._serialized_end=329
  _globals['_INVITATIONGETREQUEST']._serialized_start=331
  _globals['_INVITATIONGETREQUEST']._serialized_end=390
  _globals['_INVITATIONGETRESPONSE']._serialized_start=392
  _globals['_INVITATIONGETRESPONSE']._serialized_end=486
  _globals['_INVITATIONNEWREQUEST']._serialized_start=488
  _globals['_INVITATIONNEWREQUEST']._serialized_end=549
  _globals['_INVITATIONNEWRESPONSE']._serialized_start=551
  _globals['_INVITATIONNEWRESPONSE']._serialized_end=645
  _globals['_INVITATIONACCEPTREQUEST']._serialized_start=647
  _globals['_INVITATIONACCEPTREQUEST']._serialized_end=709
  _globals['_INVITATIONACCEPTRESPONSE']._serialized_start=711
  _globals['_INVITATIONACCEPTRESPONSE']._serialized_end=737
  _globals['_INVITATIONDECLINEREQUEST']._serialized_start=739
  _globals['_INVITATIONDECLINEREQUEST']._serialized_end=802
  _globals['_INVITATIONDECLINERESPONSE']._serialized_start=804
  _globals['_INVITATIONDECLINERESPONSE']._serialized_end=831
  _globals['_INVITATIONSASREQUEST']._serialized_start=833
  _globals['_INVITATIONSASREQUEST']._serialized_end=910
  _globals['_INVITATIONSASRESPONSE']._serialized_start=912
  _globals['_INVITATIONSASRESPONSE']._serialized_end=935
  _globals['_INVITATIONDELETEREQUEST']._serialized_start=937
  _globals['_INVITATIONDELETEREQUEST']._serialized_end=999
  _globals['_INVITATIONDELETERESPONSE']._serialized_start=1001
  _globals['_INVITATIONDELETERESPONSE']._serialized_end=1027
# @@protoc_insertion_point(module_scope)
