# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/admin/v1/backup_admin.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/admin/v1/backup_admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import backup_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_backup__pb2
from .....olvid.daemon.datatypes.v1 import client_key_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_client__key__pb2
from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(olvid/daemon/admin/v1/backup_admin.proto\x12\x15olvid.daemon.admin.v1\x1a&olvid/daemon/datatypes/v1/backup.proto\x1a*olvid/daemon/datatypes/v1/client_key.proto\x1a(olvid/daemon/datatypes/v1/identity.proto\"\x15\n\x13\x42\x61\x63kupKeyGetRequest\"5\n\x14\x42\x61\x63kupKeyGetResponse\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\"\x17\n\x15\x42\x61\x63kupKeyRenewRequest\"7\n\x16\x42\x61\x63kupKeyRenewResponse\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\"1\n\x10\x42\x61\x63kupGetRequest\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\"N\n\x11\x42\x61\x63kupGetResponse\x12\x39\n\x06\x62\x61\x63kup\x18\x01 \x01(\x0b\x32!.olvid.daemon.datatypes.v1.BackupR\x06\x62\x61\x63kup\"\x12\n\x10\x42\x61\x63kupNowRequest\"\x13\n\x11\x42\x61\x63kupNowResponse\"|\n\x1a\x42\x61\x63kupRestoreDaemonRequest\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\x12+\n\x0fnew_device_name\x18\x02 \x01(\tH\x00R\rnewDeviceName\x88\x01\x01\x42\x12\n\x10_new_device_name\"\xae\x02\n\x1b\x42\x61\x63kupRestoreDaemonResponse\x12T\n\x13restored_identities\x18\x01 \x03(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x12restoredIdentities\x12\x61\n\x1arestored_admin_client_keys\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\x17restoredAdminClientKeys\x12V\n\x14restored_client_keys\x18\x03 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\x12restoredClientKeys\"@\n\x1f\x42\x61\x63kupRestoreAdminBackupRequest\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\"\x85\x01\n BackupRestoreAdminBackupResponse\x12\x61\n\x1arestored_admin_client_keys\x18\x01 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\x17restoredAdminClientKeys\"\x95\x01\n#BackupRestoreProfileSnapshotRequest\x12\x1d\n\nbackup_key\x18\x01 \x01(\tR\tbackupKey\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12+\n\x0fnew_device_name\x18\x03 \x01(\tH\x00R\rnewDeviceName\x88\x01\x01\x42\x12\n\x10_new_device_name\"\xd0\x01\n$BackupRestoreProfileSnapshotResponse\x12P\n\x11restored_identity\x18\x01 \x01(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x10restoredIdentity\x12V\n\x14restored_client_keys\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\x12restoredClientKeysB\xb5\x01\n\x19\x63om.olvid.daemon.admin.v1B\x10\x42\x61\x63kupAdminProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODA\xaa\x02\x15Olvid.Daemon.Admin.V1\xca\x02\x15Olvid\\Daemon\\Admin\\V1\xe2\x02!Olvid\\Daemon\\Admin\\V1\\GPBMetadata\xea\x02\x18Olvid::Daemon::Admin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.admin.v1.backup_admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.olvid.daemon.admin.v1B\020BackupAdminProtoP\001Z\017olvid.io/daemon\242\002\003ODA\252\002\025Olvid.Daemon.Admin.V1\312\002\025Olvid\\Daemon\\Admin\\V1\342\002!Olvid\\Daemon\\Admin\\V1\\GPBMetadata\352\002\030Olvid::Daemon::Admin::V1'
  _globals['_BACKUPKEYGETREQUEST']._serialized_start=193
  _globals['_BACKUPKEYGETREQUEST']._serialized_end=214
  _globals['_BACKUPKEYGETRESPONSE']._serialized_start=216
  _globals['_BACKUPKEYGETRESPONSE']._serialized_end=269
  _globals['_BACKUPKEYRENEWREQUEST']._serialized_start=271
  _globals['_BACKUPKEYRENEWREQUEST']._serialized_end=294
  _globals['_BACKUPKEYRENEWRESPONSE']._serialized_start=296
  _globals['_BACKUPKEYRENEWRESPONSE']._serialized_end=351
  _globals['_BACKUPGETREQUEST']._serialized_start=353
  _globals['_BACKUPGETREQUEST']._serialized_end=402
  _globals['_BACKUPGETRESPONSE']._serialized_start=404
  _globals['_BACKUPGETRESPONSE']._serialized_end=482
  _globals['_BACKUPNOWREQUEST']._serialized_start=484
  _globals['_BACKUPNOWREQUEST']._serialized_end=502
  _globals['_BACKUPNOWRESPONSE']._serialized_start=504
  _globals['_BACKUPNOWRESPONSE']._serialized_end=523
  _globals['_BACKUPRESTOREDAEMONREQUEST']._serialized_start=525
  _globals['_BACKUPRESTOREDAEMONREQUEST']._serialized_end=649
  _globals['_BACKUPRESTOREDAEMONRESPONSE']._serialized_start=652
  _globals['_BACKUPRESTOREDAEMONRESPONSE']._serialized_end=954
  _globals['_BACKUPRESTOREADMINBACKUPREQUEST']._serialized_start=956
  _globals['_BACKUPRESTOREADMINBACKUPREQUEST']._serialized_end=1020
  _globals['_BACKUPRESTOREADMINBACKUPRESPONSE']._serialized_start=1023
  _globals['_BACKUPRESTOREADMINBACKUPRESPONSE']._serialized_end=1156
  _globals['_BACKUPRESTOREPROFILESNAPSHOTREQUEST']._serialized_start=1159
  _globals['_BACKUPRESTOREPROFILESNAPSHOTREQUEST']._serialized_end=1308
  _globals['_BACKUPRESTOREPROFILESNAPSHOTRESPONSE']._serialized_start=1311
  _globals['_BACKUPRESTOREPROFILESNAPSHOTRESPONSE']._serialized_end=1519
# @@protoc_insertion_point(module_scope)
